summaryrefslogtreecommitdiff
path: root/src/lib/analyse_audio_job.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2015-06-03 15:31:21 +0100
committerCarl Hetherington <cth@carlh.net>2015-06-03 15:31:21 +0100
commitf98caf4af896e9be943046b84586da5c2e103f18 (patch)
tree993f719e293667c432c95026dc2bfd53d5b84982 /src/lib/analyse_audio_job.h
parent92c377d1b9e781fbb4b1f1b7a76ca7dba0bd637f (diff)
Make show audio work on the whole DCP, not individual content.
Diffstat (limited to 'src/lib/analyse_audio_job.h')
-rw-r--r--src/lib/analyse_audio_job.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/lib/analyse_audio_job.h b/src/lib/analyse_audio_job.h
index ec61c0d39..cc913e1f3 100644
--- a/src/lib/analyse_audio_job.h
+++ b/src/lib/analyse_audio_job.h
@@ -26,19 +26,19 @@
#include "types.h"
class AudioBuffers;
-class AudioContent;
+class Playlist;
/** @class AnalyseAudioJob
* @brief A job to analyse the audio of a piece of AudioContent and make a note of its
* broad peak and RMS levels.
*
* After computing the peak and RMS levels over the length of the content, the job
* will write a file to Content::audio_analysis_path.
*/
class AnalyseAudioJob : public Job
{
public:
- AnalyseAudioJob (boost::shared_ptr<const Film>, boost::shared_ptr<AudioContent>);
+ AnalyseAudioJob (boost::shared_ptr<const Film>, boost::shared_ptr<const Playlist>);
std::string name () const;
std::string json_name () const;
@@ -47,7 +47,7 @@ public:
private:
void analyse (boost::shared_ptr<const AudioBuffers>);
- boost::weak_ptr<AudioContent> _content;
+ boost::shared_ptr<const Playlist> _playlist;
int64_t _done;
int64_t _samples_per_point;
std::vector<AudioPoint> _current;
@@ -26,19 +26,19 @@
/** @class AnalyseAudioJob
- * @brief A job to analyse the audio of a piece of AudioContent and make a note of its
+ * @brief A job to analyse the audio of a playlist and make a note of its
* broad peak and RMS levels.
*
@@ -26,19 +26,19 @@
* broad peak and RMS levels.
*
- * After computing the peak and RMS levels over the length of the content, the job
- * will write a file to Content::audio_analysis_path.
+ * After computing the peak and RMS levels the job will write a file
+ * to Playlist::audio_analysis_path.
*/
class AnalyseAudioJob : public Job